#!/usr/bin/env python
# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@ac-versailles.fr


#import os, shutil
import inkex
import tempfile
import Tkinter
import os
import ConfigParser
from xiaconverter.mainwindow import IADialog
from xiaconverter.loggerinkscape import LoggerInkscape

class ImageActive(inkex.Effect):
    def __init__(self):
        inkex.Effect.__init__(self)

    def effect(self):

        # fix inkscape bug 
        # https://bugs.launchpad.net/ubuntu/+source/inkscape/+bug/944077/comments/11
        pathNodes = self.document.xpath('//sodipodi:namedview',namespaces=inkex.NSS)
        pathNodes[0].set('id','base')        

        # workaround - fix path according to working dir
        # inkscape 0.47 extensions working dir is inkscape/
        # inkscape 0.48 extensions working dir is inkscape/share/extensions
        
        inkexWorkingDir = "."
        if not os.getcwd().endswith("extensions"):
            inkexWorkingDir = "share/extensions"

        # retrieve paths

        config = ConfigParser.ConfigParser()
        config.read(inkexWorkingDir + "/xia.cnf")
        numVersion = config.get('version', 'numVersion')
        releaseVersion = config.get('version', 'releaseVersion')
        imagesPath = inkexWorkingDir + "/" + config.get('paths', 'imagesPath')
        langPath = inkexWorkingDir + "/" + config.get('paths', 'langPath')
        fontsPath = inkexWorkingDir + "/" + config.get('paths', 'fontsPath')
        themesPath = inkexWorkingDir + "/" + config.get('paths', 'themesPath')        
        labjsLib = inkexWorkingDir + "/" + config.get('paths', 'labjsLib')
        jqueryLib = inkexWorkingDir + "/" + config.get('paths', 'jqueryLib')
        kineticLib = inkexWorkingDir + "/" + config.get('paths', 'kineticLib')
        sha1Lib = inkexWorkingDir + "/" + config.get('paths', 'sha1Lib')       
        
        try:
            filePath = tempfile.mkdtemp() + "/" + "temp.svg"
            with open(filePath,"w") as file:
                self.document.write(filePath)
            console = LoggerInkscape()

            root = Tkinter.Tk()
            root.title("XIA " + numVersion + releaseVersion)
            root.geometry("465x310")
            root.resizable(0,0)
            img = Tkinter.PhotoImage(file= imagesPath + '/xia64.gif')
            root.tk.call('wm', 'iconphoto', root._w, img)  
            maindialog = IADialog(root, console, langPath, imagesPath, themesPath, fontsPath, labjsLib, jqueryLib,
                                  kineticLib, sha1Lib, filePath)
            maindialog.pack(side="left")
            root.mainloop()

        except ValueError:
           #inkex.debug(ValueError)
           pass
                              
ia = ImageActive()
ia.affect()
          			



#!/usr/bin/env python
"""
simplepath.py
functions for digesting paths into a simple list structure

Copyright (C) 2005 Aaron Spike, aaron@ekips.org

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

source code from inkscape extensions


"""
import re, math

def lexPath(d):
    """
    returns and iterator that breaks path data 
    identifies command and parameter tokens
    """
    offset = 0
    length = len(d)
    delim = re.compile(r'[ \t\r\n,]+')
    command = re.compile(r'[MLHVCSQTAZmlhvcsqtaz]')
    parameter = re.compile(r'(([-+]?[0-9]+(\.[0-9]*)?|[-+]?\.[0-9]+)([eE][-+]?[0-9]+)?)')
    while 1:
        m = delim.match(d, offset)
        if m:
            offset = m.end()
        if offset >= length:
            break
        m = command.match(d, offset)
        if m:
            yield [d[offset:m.end()], True]
            offset = m.end()
            continue
        m = parameter.match(d, offset)
        if m:
            yield [d[offset:m.end()], False]
            offset = m.end()
            continue
        #TODO: create new exception
        raise Exception, 'Invalid path data!'
'''
pathdefs = {commandfamily:
    [
    implicitnext,
    #params,
    [casts,cast,cast],
    [coord type,x,y,0]
    ]}
'''
pathdefs = {
    'M':['L', 2, [float, float], ['x','y']], 
    'L':['L', 2, [float, float], ['x','y']], 
    'H':['H', 1, [float], ['x']], 
    'V':['V', 1, [float], ['y']], 
    'C':['C', 6, [float, float, float, float, float, float], ['x','y','x','y','x','y']], 
    'S':['S', 4, [float, float, float, float], ['x','y','x','y']], 
    'Q':['Q', 4, [float, float, float, float], ['x','y','x','y']], 
    'T':['T', 2, [float, float], ['x','y']], 
    'A':['A', 7, [float, float, float, int, int, float, float], ['r','r','a',0,'s','x','y']], 
    'Z':['L', 0, [], []]
    }
def parsePath(d):
    """
    Parse SVG path and return an array of segments.
    Removes all shorthand notation.
    Converts coordinates to absolute.
    """
    retval = []
    lexer = lexPath(d)

    pen = (0.0,0.0)
    subPathStart = pen
    lastControl = pen
    lastCommand = ''
    
    while 1:
        try:
            token, isCommand = lexer.next()
        except StopIteration:
            break
        params = []
        needParam = True
        if isCommand:
            if not lastCommand and token.upper() != 'M':
                raise Exception, 'Invalid path, must begin with moveto.'    
            else:                
                command = token
        else:
            #command was omited
            #use last command's implicit next command
            needParam = False
            if lastCommand:
                if lastCommand.isupper():
                    command = pathdefs[lastCommand][0]
                else:
                    command = pathdefs[lastCommand.upper()][0].lower()
            else:
                raise Exception, 'Invalid path, no initial command.'    
        numParams = pathdefs[command.upper()][1]
        while numParams > 0:
            if needParam:
                try: 
                    token, isCommand = lexer.next()
                    if isCommand:
                        raise Exception, 'Invalid number of parameters'
                except StopIteration:
                    raise Exception, 'Unexpected end of path'
            cast = pathdefs[command.upper()][2][-numParams]
            param = cast(token)
            if command.islower():
                if pathdefs[command.upper()][3][-numParams]=='x':
                    param += pen[0]
                elif pathdefs[command.upper()][3][-numParams]=='y':
                    param += pen[1]
            params.append(param)
            needParam = True
            numParams -= 1
        #segment is now absolute so
        outputCommand = command.upper()
    
        #Flesh out shortcut notation    
        if outputCommand in ('H','V'):
            if outputCommand == 'H':
                params.append(pen[1])
            if outputCommand == 'V':
                params.insert(0,pen[0])
            outputCommand = 'L'
        if outputCommand in ('S','T'):
            params.insert(0,pen[1]+(pen[1]-lastControl[1]))
            params.insert(0,pen[0]+(pen[0]-lastControl[0]))
            if outputCommand == 'S':
                outputCommand = 'C'
            if outputCommand == 'T':
                outputCommand = 'Q'

        #current values become "last" values
        if outputCommand == 'M':
            subPathStart = tuple(params[0:2])
            pen = subPathStart
        if outputCommand == 'Z':
            pen = subPathStart
        else:
            pen = tuple(params[-2:])

        if outputCommand in ('Q','C'):
            lastControl = tuple(params[-4:-2])
        else:
            lastControl = pen
        lastCommand = command

        retval.append([outputCommand,params])
    return retval

def formatPath(a):
    """Format SVG path data from an array"""
    return "".join([cmd + " ".join([str(p) for p in params]) for cmd, params in a])

def translatePath(p, x, y):
    for cmd,params in p:
        defs = pathdefs[cmd]
        for i in range(defs[1]):
            if defs[3][i] == 'x':
                params[i] += x
            elif defs[3][i] == 'y':
                params[i] += y

def scalePath(p, x, y):
    for cmd,params in p:
        defs = pathdefs[cmd]
        for i in range(defs[1]):
            if defs[3][i] == 'x':
                params[i] *= x
                
            elif defs[3][i] == 'y':
                params[i] *= y
                
            elif defs[3][i] == 'r':         # radius parameter
                params[i] *= x
                
            elif defs[3][i] == 's':         # sweep-flag parameter
                if x*y < 0:
                    params[i] = 1 - params[i]
            elif defs[3][i] == 'a':         # x-axis-rotation angle
                if y < 0:
                    params[i] = - params[i]

def rotatePath(p, a, cx = 0, cy = 0):
    if a == 0:
        return p
    for cmd,params in p:
        defs = pathdefs[cmd]
        for i in range(defs[1]):
            if defs[3][i] == 'x':
                x = params[i] - cx
                y = params[i + 1] - cy
                r = math.sqrt((x**2) + (y**2))
                if r != 0:
                    theta = math.atan2(y, x) + a
                    params[i] = (r * math.cos(theta)) + cx
                    params[i + 1] = (r * math.sin(theta)) + cy


# vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 encoding=utf-8 textwidth=99



#! /usr/bin/python

# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@ac-versailles.fr

import os
import shutil
import imp
import sys
from iaobject import iaObject
from pikipiki import PageFormatter

class XIAConsole():

    def __init__(self, langPath, themesPath, fontsPath, labjsLib, jqueryLib, kineticLib, sha1Lib, svgfile, output_dir,
                 selected_theme, console):

        self.themesPath = themesPath
        self.langPath = langPath
        self.fontsPath = fontsPath
        self.labjsLib = labjsLib
        self.kineticLib = kineticLib
        self.sha1Lib = sha1Lib
        self.jqueryLib = jqueryLib
        self.resize = 3
        self.filename = svgfile
        self.dirname = output_dir
        self.theme = {}
        self.index_standalone = 0
        self.firefoxos = 0 
        
        if not os.path.isdir(self.themesPath + "/" + selected_theme):
            selected_theme = "accordionBlack"
        self.theme['name'] = selected_theme

        self.imageActive = iaObject(console)

        imp.load_source(selected_theme, themesPath + "/" + selected_theme + \
            "/hook.py")
        imported_class = __import__(selected_theme)
        self.theme['object'] = imported_class.hook(self, self.imageActive, \
            PageFormatter, self.langPath)


    def createIA(self):

        if not self.index_standalone:
            if os.path.isdir(self.dirname + '/font'):
                shutil.rmtree(self.dirname + '/font')              
            if os.path.isdir(self.dirname + '/img'):
                shutil.rmtree(self.dirname + '/img')
            if os.path.isdir(self.dirname + '/css'):
                shutil.rmtree(self.dirname + '/css')
            if os.path.isdir(self.dirname + '/js'):
                shutil.rmtree(self.dirname + '/js')
            if os.path.isdir(self.dirname + '/datas'):
                shutil.rmtree(self.dirname + '/datas')
            os.mkdir(self.dirname + '/datas')
            shutil.copytree(self.fontsPath , self.dirname + '/font/')              
            shutil.copytree(self.themesPath + '/' + self.theme['name'] + \
                '/css/', self.dirname + '/css/')
            shutil.copytree(self.themesPath + '/' + self.theme['name'] + \
                '/img/', self.dirname + '/img/')
            shutil.copytree(self.themesPath + '/' + self.theme['name'] + \
                '/js/', self.dirname + '/js/')
            shutil.copy(self.labjsLib , self.dirname + '/js')
            shutil.copy(self.jqueryLib , self.dirname + '/js')
            shutil.copy(self.kineticLib , self.dirname + '/js')
            shutil.copy(self.sha1Lib , self.dirname + '/js')
        if self.firefoxos:
            shutil.copyfile(self.themesPath + '/' + self.theme['name'] + \
                '/manifest.webapp', self.dirname + '/manifest.webapp')

            shutil.copyfile(self.themesPath + '/' + self.theme['name'] + \
                '/deploy.html', self.dirname + '/deploy.html')

        maxNumPixels = self.defineMaxPixels(self.resize)
        self.imageActive.analyzeSVG(self.filename, maxNumPixels)

        self.imageActive.generateJSON()

        if not self.index_standalone:
            with open(self.dirname + '/datas/data.js',"w") as jsonfile:
                jsonfile.write(self.imageActive.jsonContent.encode('utf8'))
            self.theme['object'].generateIndex(self.dirname + "/index.html", \
                self.themesPath + '/' + self.theme['name'] + '/index.html')
        else:
            self.theme['object'].generateIndex(self.dirname + "/index.html", \
                self.themesPath + '/' + self.theme['name'] + '/index_standalone.html')


    def defineMaxPixels(self, resizeCoeff):
        if resizeCoeff == 0:
            return float(512 * 512)
        elif resizeCoeff == 1:
            return float(1024 * 1024)            
        elif resizeCoeff == 2:
            return float(3 * 1024 * 1024)            
        elif resizeCoeff == 3:
            return float(5 * 1024 * 1024)            
        else:
            return float(512 * 1024)     


#!/usr/bin/python
# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@ac-versailles.fr

from xiaconverter.ctm import CurrentTransformation
from nose.tools import *
import math

import xiaconverter.cubicsuperpath

class TestCurrentTransformation:

    def test_analyze_translate(self):
        ctm = CurrentTransformation()
        ctm.analyze("translate( 10   )")
        assert_equal(ctm.translateX, "10")
        assert_equal(ctm.translateY, "10")
        assert_equal(ctm.matrix, [[1.0, 0.0, 10.0], [0.0, 1.0, 10.0]])

    def test_analyze_translate2(self):
        ctm = CurrentTransformation()

        ctm.analyze("translate(10   20)")
        assert_equal(ctm.translateX, "10")
        assert_equal(ctm.translateY, "20")
        assert_equal(ctm.matrix, [[1.0, 0.0, 10.0], [0.0, 1.0, 20.0]])

    def test_analyze_translate3(self):
        ctm = CurrentTransformation()

        ctm.analyze("translate(10   , -10)")
        assert_equal(ctm.translateX, "10")
        assert_equal(ctm.translateY, "-10")
        assert_equal(ctm.matrix, [[1.0, 0.0, 10.0], [0.0, 1.0, -10.0]])		


    def test_analyze_scale(self):
        ctm = CurrentTransformation()
        ctm.analyze("scale(10)")
        assert_equal(ctm.scaleX, "10")
        assert_equal(ctm.scaleY, "10")
        assert_equal(ctm.matrix, [[10, 0.0, 0.0], [0.0, 10, 0.0]])

    def test_analyze_scale2(self):
        ctm = CurrentTransformation()

        ctm.analyze("scale(10 20)")
        assert_equal(ctm.scaleX, "10")
        assert_equal(ctm.scaleY, "20")
        assert_equal(ctm.matrix, [[10, 0.0, 0.0], [0.0, 20, 0.0]])

    def test_analyze_scale3(self):
        ctm = CurrentTransformation()

        ctm.analyze("scale(10,-10)")
        assert_equal(ctm.scaleX, "10")
        assert_equal(ctm.scaleY, "-10")
        assert_equal(ctm.matrix, [[10, 0.0, 0.0], [0.0, -10, 0.0]])		

    def test_analyze_rotate(self):
        ctm = CurrentTransformation()
        ctm.analyze("rotate(10 20 -30)")
        assert_equal(ctm.rotate, "10")
        assert_equal(ctm.rX, "20")
        assert_equal(ctm.rY, "-30")		
        assert_equal(ctm.matrix, 
            [ 
                [
                    math.cos(10), 
                    -math.sin(10), 
                    -20 * math.cos(10) - 30 * math.sin(10) + 20
                ], 
                [
                    math.sin(10), 
                    math.cos(10), 
                    -20 * math.sin(10) + 30 * math.cos(10) - 30
                ]
            ])

    def test_analyze_rotate2(self):
        ctm = CurrentTransformation()

        ctm.analyze("rotate(10)")
        assert_equal(ctm.rotate, "10")
        assert_equal(ctm.rX, "0")
        assert_equal(ctm.rY, "0")		
        assert_equal(ctm.matrix, 
            [ 
                [
                    math.cos(10), 
                    -math.sin(10), 
                    0
                ], 
                [
                    math.sin(10), 
                    math.cos(10), 
                    0
                ]
            ])

    def test_analyze_matrix(self):
        ctm = CurrentTransformation()
        ctm.analyze("matrix(1 2 3 4 5 6)")
        assert_equal(ctm.translateX, "5")
        assert_equal(ctm.translateY, "6")
        assert_equal(ctm.scaleX, math.sqrt(float(1)**2+float(3)**2))
        assert_equal(ctm.scaleY, math.sqrt(float(2)**2+float(4)**2))
        assert_equal(ctm.rotate, math.atan2(float(2),float(4)))                
        # @TODO assert_equal(ctm.rX, ??)
        # @TODO assert_equal(ctm.rY, ??)		
        assert_equal(ctm.matrix, [[1.0,3.0,5.0],[2.0,4.0,6.0]])

    def test_analyze_rectToPath(self):
        ctm = CurrentTransformation()
        rect = {
            'x': 10,
            'y': 20,
            'width': 50,
            'height': 30
        }
        path = ctm.rectToPath(rect)
        assert_equal(path, "M 10.000000,20.000000 L 60.000000,20.000000 L 60.000000,50.000000 L 10.000000,50.000000 L 10.000000,20.000000 ")

    def test_analyze_rectToPath2(self):
        ctm = CurrentTransformation()

        rect = {
            'x': 10,
            'y': 20,
            'width': 50,
            'height': 30,
            'rx': 5,
            'ry': 10
        }
        path = ctm.rectToPath(rect)
        assert_equal(path, "M 15.000000,20.000000 L 55.000000,20.000000 A 5.000000,10.000000 0 0 1 60.000000,30.000000L 60.000000,40.000000 A 5.000000,10.000000 0 0 1 55.000000,50.000000L 15.000000,50.000000 A 5.000000,10.000000 0 0 1 10.000000,40.000000L 10.000000,30.000000 A 5.000000,10.000000 0 0 1 15.000000,20.000000")

    def test_analyze_rectToPath3(self):
        ctm = CurrentTransformation()

        rect = {
            'x': 10,
            'y': 10,
            'width': 40,
            'height': 40,
            'rx': 20,
            'ry': 20
        }
        path = ctm.rectToPath(rect)
        assert_equal(path, "M 30.000000,10.000000 L 30.000000,10.000000 A 20.000000,20.000000 0 0 1 50.000000,30.000000L 50.000000,30.000000 A 20.000000,20.000000 0 0 1 30.000000,50.000000L 30.000000,50.000000 A 20.000000,20.000000 0 0 1 10.000000,30.000000L 10.000000,30.000000 A 20.000000,20.000000 0 0 1 30.000000,10.000000")


    def test_analyze_applyTransformToPath(self):
        matrix = [[1, 2, 3], [4, 5, 6]]
        ctm = CurrentTransformation()
        path = "M 10,20 L 60,20 L 60,50 L 10,50 L 10,20"
        path_modified = "M53.0 146.0C53.0 146.0 103.0 346.0 103.0 346.0C103.0 346.0 163.0 496.0 163.0 496.0C163.0 496.0 113.0 296.0 113.0 296.0C113.0 296.0 53.0 146.0 53.0 146.0"
        p = xiaconverter.cubicsuperpath.parsePath(path)
        ctm.applyTransformToPath(matrix,p)
        path_calculated = xiaconverter.cubicsuperpath.formatPath(p)
        assert_equal(path_calculated,path_modified)



#! /usr/bin/python
# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@ac-versailles.fr

import Tkinter
import tkFileDialog
import os
import shutil
import imp
import sys
import ConfigParser
from iaobject import iaObject
from pikipiki import PageFormatter
from splashscreen import Splash
from tooltip import ToolTip
from paramswindow import IAParams

import gettext
import locale
if sys.platform.startswith('win32'):
    import ctypes

class IADialog(Tkinter.Frame):

    def __init__(self, root, console, langPath, imagesPath, themesPath, fontsPath, labjsLib, jqueryLib, kineticLib,
                 sha1Lib, svgfile=''):

        Tkinter.Frame.__init__(self, root)

        try:
            t = gettext.translation("xia-converter", langPath, languages=[locale.getdefaultlocale()[0]])
        except:
            t = gettext.translation("xia-converter", langPath, languages=['en_US'])
        translate = t.ugettext

        self.filename = ""
        self.imagesPath = imagesPath
        self.themesPath = themesPath
        self.fontsPath = fontsPath
        self.langPath = langPath
        self.labjsLib = labjsLib
        self.kineticLib = kineticLib
        self.sha1Lib = sha1Lib
        self.jqueryLib = jqueryLib
        self.root = root
        self.resize = 0
        self.firefoxos = 0
        self.index_standalone = 0

        # Don't show hidden files and directories 
        # (with tkinter, by default, it's the opposite).
        root.tk.call('namespace', 'import', '::tk::dialog::file::')
        root.call('set', '::tk::dialog::file::showHiddenVar', '0')
        root.call('set', '::tk::dialog::file::showHiddenBtn', '1')

        # define images

        import_img= Tkinter.PhotoImage(file=self.imagesPath + "/open.gif")
        ia_img= Tkinter.PhotoImage(file=self.imagesPath + "/ia.gif")    
        file_locked= Tkinter.PhotoImage(file=self.imagesPath + "/file_locked.gif")    
        void_img= Tkinter.PhotoImage(file=self.imagesPath + "/void.gif")
        params_img= Tkinter.PhotoImage(file=self.imagesPath + "/params.gif")            

        self.filename = svgfile

        # init Image Active Object

        self.imageActive = iaObject(console)

        # define buttons

        if self.filename == "":
            button1 = Tkinter.Button(self, image=import_img,
                                     relief=Tkinter.FLAT, bd=0, height=150, width=150,
                                     command=self.askopenfilename)
            button1.image = import_img
            button1.grid(row=0,column=0, columnspan=1,sticky='W')
            tooltip = ToolTip(button1,translate("select svg file"), None, 0.1)
            self.keep_alive = "yes"
        else:
            label1 = Tkinter.Label(self, image=file_locked)
            label1.photo = file_locked
            label1.grid(row=0,column=0,columnspan=1, sticky='W')
            self.keep_alive = "no"

        button2 = Tkinter.Button(self, image=params_img,
                                 relief=Tkinter.FLAT, bd=0, height=150, width=150,
                                 command=self.openparams)
        button2.image = params_img
        button2.grid(row=0,column=1, columnspan=1,sticky='W')
        tooltip2 = ToolTip(button2,translate("ajust parameters"), None, 0.1)

        # Automatic import of themes
        
        self.themes = []

        if os.path.isdir(themesPath):
            theme_index = 2
            themes_folders = sorted(os.listdir(themesPath))
            for filename in themes_folders:
                theme = {}
                theme['name'] = filename
                imp.load_source(filename, themesPath + "/" + filename + "/hook.py")
                imported_class = __import__(filename)
                theme['object'] = imported_class.hook(self, self.imageActive, PageFormatter, self.langPath)
                self.themes.append(theme)

                img_button = Tkinter.PhotoImage(file= themesPath + "/" + filename + "/" + "icon.gif")
                button = Tkinter.Button(self, image=img_button, relief=Tkinter.FLAT,bd=0, height=150, width=150)
                button["command"] = lambda t=theme:self.createIA(t)
                button.image = img_button
                button.grid(row=theme_index // 3,column=theme_index % 3)
                tooltip = ToolTip(button,theme['object'].tooltip, None, 0.1)
                theme_index += 1
                if theme_index == 3:
                    theme_index = 5

        # padding

        while (theme_index % 3) != 0:
            label = Tkinter.Label(self, image=void_img)
            label.photo = void_img
            label.grid(row=theme_index // 3, column=theme_index % 3, columnspan=1, sticky='W')
            theme_index += 1
            if theme_index == 3:
                theme_index = 5

        # redefine window height if necessary

        root.geometry("465x" + str((theme_index // 3) * 155))

        # title

        label = Tkinter.Label(self, image=ia_img)
        label.photo = ia_img
        label.grid(row=1,column=0,columnspan=2, sticky='W')

        # define options for opening or saving a file

        self.file_opt = options = {}
        options['defaultextension'] = '.svg'
        options['filetypes'] = [('svg files', '.svg')]

        if sys.platform.startswith('win32'):
            options['initialdir'] = self.getwinuser()
        else:
            options['initialdir'] = os.path.expanduser('~')
        options['initialfile'] = translate('myfile.svg')
        options['parent'] = root
        options['title'] = translate('Select a svg file')

        self.dir_opt = options = {}

        if sys.platform.startswith('win32'):
            options['initialdir'] = self.getwinuser()
        else:
            options['initialdir'] = os.path.expanduser('~')
        options['mustexist'] = False
        options['parent'] = root
        options['title'] = translate('Select target folder')

        # retrieves source and target directories from config file

        # Creation of config_dir if not exists.
        if sys.platform.startswith('win32'):
            self.home_dir = self.getwinuser()
        else:
            self.home_dir = os.path.expanduser('~')
        self.config_dir = os.path.join(self.home_dir, '.xia')
        self.config_ini = os.path.join(self.config_dir, 'config.ini')
        if not os.path.isdir(self.config_dir):
            try:
                os.mkdir(self.config_dir, 0755)
            except Exception as e:
                console.display(translate("Sorry, impossible to create the {0} directory") . format(self.config_dir))
                console.display("Error({0}): {1}".format(e.errno, e.strerror))
                sys.exit(1)
                
        if os.path.isfile(self.config_ini):
            self.config = ConfigParser.ConfigParser()
            self.config.read(self.config_ini)
            try:
                self.file_opt['initialdir'] = self.config.get("paths", "source_dir").decode("base64")
            except:
                self.config.set("paths", "source_dir", self.file_opt['initialdir'].encode("utf8").encode("base64"))
                self.config.write(self.config_ini)
            try:
                self.dir_opt['initialdir'] = self.config.get("paths", "target_dir").decode("base64")
            except:
                self.config.set("paths", "target_dir", self.dir_opt['initialdir'].encode("utf8").encode("base64"))
                self.config.write(self.config_ini)
        else:
            with open(self.config_ini, "w") as config_file:
                self.config = ConfigParser.ConfigParser()
                self.config.add_section('paths')
                self.config.set("paths", "source_dir", self.file_opt['initialdir'].encode("utf8").encode("base64"))
                self.config.set("paths", "target_dir", self.dir_opt['initialdir'].encode("utf8").encode("base64"))
                self.config.write(config_file)

        self.paramsTitle = translate("Parameters")

    def getwinuser(self):
        """ fix python2 bug on os.path.expanduser
        http://bugs.python.org/issue13207
        """
        buf = ctypes.create_unicode_buffer(1024)
        ctypes.windll.kernel32.GetEnvironmentVariableW(u"USERPROFILE", buf, 1024)
        return buf.value        
    
    
    def openparams(self):
        try:
            self.params.focus()
            self.params.lift()
        except:
            self.params = Tkinter.Toplevel()
            self.params.title(self.paramsTitle)
            self.params.geometry("465x155")
            self.params.resizable(0,0)
            img = Tkinter.PhotoImage(file=self.imagesPath + '/xia64.gif')
            self.params.tk.call('wm', 'iconphoto', self.params._w, img)    
            IAParams(self.params, self, self.langPath, self.imagesPath).pack(side="left")
        
    def askopenfilename(self):
        self.filename = tkFileDialog.askopenfilename(**self.file_opt)
        if self.filename:
            head, tail = os.path.split(self.filename)
            self.file_opt['initialdir'] = head
            self.config.set("paths", "source_dir", head.encode("utf8").encode("base64"))
            with open(self.config_ini, "w") as config_file:
                self.config.write(config_file)

    def createIA(self, theme):
        if self.filename:
            self.dirname = tkFileDialog.askdirectory(**self.dir_opt)
            if self.dirname:
                self.config.set("paths", "target_dir", self.dirname.encode("utf8").encode("base64"))
                with open(self.config_ini, "w") as config_file:
                  self.config.write(config_file)

                mysplash = Splash(self.root, self.imagesPath + '/processing.gif', 0)
                mysplash.enter()              

                self.dir_opt['initialdir'] = self.dirname
                if not self.index_standalone:
                    if os.path.isdir(self.dirname + '/font'):
                        shutil.rmtree(self.dirname + '/font')              
                    if os.path.isdir(self.dirname + '/img'):
                        shutil.rmtree(self.dirname + '/img')
                    if os.path.isdir(self.dirname + '/css'):
                        shutil.rmtree(self.dirname + '/css')
                    if os.path.isdir(self.dirname + '/js'):
                        shutil.rmtree(self.dirname + '/js')
                    if os.path.isdir(self.dirname + '/datas'):
                        shutil.rmtree(self.dirname + '/datas')
                    os.mkdir(self.dirname + '/datas')
                    shutil.copytree(self.fontsPath , self.dirname + '/font/')              
                    shutil.copytree(self.themesPath + '/' + theme['name'] + '/css/', self.dirname + '/css/')
                    shutil.copytree(self.themesPath + '/' + theme['name'] + '/img/', self.dirname + '/img/')
                    shutil.copytree(self.themesPath + '/' + theme['name'] + '/js/', self.dirname + '/js/')
                    shutil.copy(self.labjsLib, self.dirname + '/js')
                    shutil.copy(self.jqueryLib, self.dirname + '/js')
                    shutil.copy(self.kineticLib, self.dirname + '/js')
                    shutil.copy(self.sha1Lib, self.dirname + '/js')

                if self.firefoxos:
                    shutil.copyfile(self.themesPath + '/' + theme['name'] + '/manifest.webapp',
                                    self.dirname + '/manifest.webapp')

                    shutil.copyfile(self.themesPath + '/' + theme['name'] + '/deploy.html',
                                    self.dirname + '/deploy.html')

                maxNumPixels = self.defineMaxPixels(self.resize)
                self.imageActive.analyzeSVG(self.filename, maxNumPixels)
                
                self.imageActive.generateJSON()
                if not self.index_standalone:
                    with open(self.dirname + '/datas/data.js',"w") as jsonfile:
                        jsonfile.write(self.imageActive.jsonContent.encode('utf8'))

                theme['object'].generateIndex(self.dirname + "/index.html",
                                              self.themesPath + '/' + theme['name'] + '/index.html')
                    
                mysplash.exit()

                if self.keep_alive == "no":
                    # destroy method generates error in inkscape
                    sys.exit()

    def defineMaxPixels(self, resizeCoeff):
        if resizeCoeff == 0:
            return float(1024 * 1024)
        elif resizeCoeff == 1:
            return float(2 * 1024 * 1024)
        elif resizeCoeff == 2:
            return float(3 * 1024 * 1024)            
        elif resizeCoeff == 3:
            return float(5 * 1024 * 1024)            
        else:
            return float(512 * 1024)            
            
    def quit(self):
        self.root.destroy()



#! /usr/bin/python
# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@ac-versailles.fr

import Tkinter
import tkFileDialog
from tooltip import ToolTip

import gettext
import locale


class IAParams(Tkinter.Frame):

    def __init__(self, root, parent, langPath, imagesPath):

        Tkinter.Frame.__init__(self, root)

        try:
            t = gettext.translation("xia-converter", langPath, languages=[locale.getdefaultlocale()[0]])
        except:
            t = gettext.translation("xia-converter", langPath, languages=['en_US'])
        translate = t.ugettext

        self.root = root
        self.parent = parent
        self.resizeCoeff = parent.resize
        
        self.firefoxos_param = parent.firefoxos
        self.indexStandalone_param = parent.index_standalone
        
        # define images
        self.resize_img = {}
        self.resize_img[0]= Tkinter.PhotoImage(file=imagesPath + \
            "/resize1.gif")            
        self.resize_img[1]= Tkinter.PhotoImage(file=imagesPath + \
            "/resize2.gif")            
        self.resize_img[2]= Tkinter.PhotoImage(file=imagesPath + \
            "/resize3.gif")            
        self.resize_img[3]= Tkinter.PhotoImage(file=imagesPath + \
            "/resize4.gif")            
            
        params_img= Tkinter.PhotoImage(file=imagesPath + \
            "/params.gif")            

        self.firefoxos_img = {}
        self.firefoxos_img[0] = Tkinter.PhotoImage(file=imagesPath + \
            "/firefoxos_disabled.gif")
        self.firefoxos_img[1] = Tkinter.PhotoImage(file=imagesPath + \
            "/firefoxos_enabled.gif")

        self.indexStandalone_img = {}
        self.indexStandalone_img[0] = Tkinter.PhotoImage(file=imagesPath + \
            "/indexStandalone_disabled.gif")
        self.indexStandalone_img[1] = Tkinter.PhotoImage(file=imagesPath + \
            "/indexStandalone_enabled.gif")            
            
        # define buttons

        self.button_resize = Tkinter.Button(self, \
          image=self.resize_img[self.resizeCoeff % 4], \
          relief=Tkinter.FLAT, bd=0, height=150, width=150, \
          command=self.resize)
        self.button_resize.image = self.resize_img[self.resizeCoeff % 4]
        self.button_resize.grid(row=0,column=0, columnspan=1,sticky='W')
        tooltip = ToolTip(self.button_resize,translate("modify image resolution"), None, 0.1)

        self.button_firefox = Tkinter.Button(self, \
          image=self.firefoxos_img[self.firefoxos_param], \
          relief=Tkinter.FLAT, bd=0, height=150, width=150, \
          command=self.firefox)
        self.button_firefox.image = self.firefoxos_img[self.firefoxos_param]
        self.button_firefox.grid(row=0,column=1, columnspan=1,sticky='W')
        tooltip2 = ToolTip(self.button_firefox,translate("create firefox OS files"), None, 0.1)

        self.button_indexStandalone = Tkinter.Button(self, \
          image=self.indexStandalone_img[self.indexStandalone_param], \
          relief=Tkinter.FLAT, bd=0, height=150, width=150, \
          command=self.indexStandalone)
        self.button_indexStandalone.image = self.indexStandalone_img[self.indexStandalone_param]
        self.button_indexStandalone.grid(row=0,column=2, columnspan=1,sticky='W')
        tooltip3 = ToolTip(self.button_indexStandalone,translate("index standalone"), None, 0.1)

        # title

        #label = Tkinter.Label(self, image=params_img)
        #label.photo = params_img
        #label.grid(row=1,column=0,columnspan=1, sticky='W')

    def resize(self):
        self.resizeCoeff = (self.resizeCoeff + 1) % 4
        self.parent.resize = self.resizeCoeff
        self.button_resize.configure(image=self.resize_img[self.resizeCoeff])
        
    def firefox(self):
        self.firefoxos_param = (self.firefoxos_param + 1) % 2
        self.parent.firefoxos = self.firefoxos_param
        self.button_firefox.configure(image=self.firefoxos_img[self.firefoxos_param])

        if self.firefoxos_param == 1:
            self.indexStandalone_param = 0
            self.parent.index_standalone = self.indexStandalone_param
            self.button_indexStandalone.configure(image=self.indexStandalone_img[self.indexStandalone_param])           
        
    def indexStandalone(self):
        self.indexStandalone_param = (self.indexStandalone_param + 1) % 2
        self.parent.index_standalone = self.indexStandalone_param
        self.button_indexStandalone.configure(image=self.indexStandalone_img[self.indexStandalone_param])

        if self.indexStandalone_param == 1:
            self.firefoxos_param = 0
            self.parent.firefoxos = self.firefoxos_param
            self.button_firefox.configure(image=self.firefoxos_img[self.firefoxos_param])        

        
    def quit(self):
        self.root.destroy()



#!/usr/bin/python
# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@ac-versailles.fr

from xiaconverter.iaobject import iaObject
from xiaconverter.logger import Logger
from nose.tools import *
from xml.dom import minidom
import tempfile
import os
import tempfile

class LoggerMock(Logger):
    def display(self, msg):
        pass

class TestiaObject:
    def test_analyzeSVG(self):
        console = LoggerMock()
        ia = iaObject(console)
        maxNumPixels = 5 * 1024 * 1024
        currentDir  = os.path.dirname(os.path.realpath(__file__))
        ia.analyzeSVG(currentDir + "/fixtures/inkscape1.svg", maxNumPixels)
        assert_equal(ia.scene['width'], '50')
        assert_equal(ia.scene['height'], '50')
        assert_equal(ia.scene['image'], 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAADIAAAAyCAYAAAAeP4ixAAAT+ElEQVR4nI2ayY9dx5Xmfyci7r1v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\nzFYsd77+/T/81fB79/RHHjz7/zRmUPKadwHiAAAAAElFTkSuQmCC\n')
        assert_equal(ia.scene['creator'], 'creator')
        assert_equal(ia.scene['description'], 'description')
        assert_equal(ia.scene['title'], 'fixture 1')

    def test_analyzeSVG2(self):

        tempDirSvg = tempfile.gettempdir()
        maxNumPixels = 5 * 1024 * 1024
        currentDir  = os.path.dirname(os.path.realpath(__file__))
        with open(currentDir + "/fixtures/generic1.svg", "r") as genericSvg:
            tempContent = genericSvg.read()
            tempContent = tempContent.replace("file://fixtures", "file://" + currentDir + "/fixtures")

        with open(tempDirSvg + "/generic1.svg", "w") as tempSvg:
            tempSvg.write(tempContent)
        console = LoggerMock()
        ia = iaObject(console)
        ia.analyzeSVG(tempSvg.name, maxNumPixels)
        
        assert_equal(ia.scene['width'], '10')
        assert_equal(ia.scene['height'], '10')
        assert_equal(ia.details[0]['width'], '152')
        assert_equal(ia.details[0]['height'], '161')

    def test_analyzeSVG3(self):
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?>\
            <desc>description</desc>")
        desc = dom1.getElementsByTagName('desc')
        assert_equal("description", ia.get_tag_value(desc[0]))

        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?><desc></desc>")
        desc = dom1.getElementsByTagName('desc')
        assert_equal("",ia.get_tag_value(desc[0]))

    def test_analyzeSVG4(self):

        # check root path
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?>\
            <svg>\
                <path d='M 0,0 L 10,0 L 10,10 L 0,10 L 0,0 z' />\
            </svg>")
        path = dom1.getElementsByTagName('path')
        newrecord = ia.extract_path(path[0], "")
        assert_equal(newrecord['path'], '"M0.0 0.0C0.0 0.0 10.0 0.0 10.0 0.0C10.0 0.0 10.0 10.0 10.0 10.0C10.0 10.0 0.0 10.0 0.0 10.0C0.0 10.0 0.0 0.0 0.0 0.0C0.0 0.0 0.0 0.0 0.0 0.0 z"')
        assert_equal(newrecord['maxX'], '10.0')
        assert_equal(newrecord['maxY'], '10.0')
        assert_equal(newrecord['minX'], '0.0')
        assert_equal(newrecord['minY'], '0.0')
        assert_equal(newrecord['x'], '0')
        assert_equal(newrecord['y'], '0')

    def test_analyzeSVG4(self):
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?>\
            <svg>\
                <path \
                    transform='translate(10)'\
                    x='10'\
                    y='30'\
                    d='M 0,0 L 10,0 L 10,10 L 0,10 L 0,0 z' />\
            </svg>")
        path = dom1.getElementsByTagName('path')
        newrecord = ia.extract_path(path[0], "")
        assert_equal(newrecord['path'], '"M10.0 10.0C10.0 10.0 20.0 10.0 20.0 10.0C20.0 10.0 20.0 20.0 20.0 20.0C20.0 20.0 10.0 20.0 10.0 20.0C10.0 20.0 10.0 10.0 10.0 10.0C10.0 10.0 10.0 10.0 10.0 10.0 z"')
        assert_equal(newrecord['maxX'], '20.0')
        assert_equal(newrecord['maxY'], '20.0')
        assert_equal(newrecord['minX'], '10.0')
        assert_equal(newrecord['minY'], '10.0')
        assert_equal(newrecord['x'], '10')
        assert_equal(newrecord['y'], '30')

    def test_analyzeSVG4(self):

        # check path included in a group
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?>\
            <g>\
                <path \
                    transform='translate(10)'\
                    x='10'\
                    y='30'\
                    d='M 0,0 L 10,0 L 10,10 L 0,10 L 0,0 z' />\
            </g>")
        group = dom1.getElementsByTagName('g')
        newrecord = ia.extract_g(group[0], "")
        assert_equal(newrecord["group"][0]['path'], '"M10.0 10.0C10.0 10.0 20.0 10.0 20.0 10.0C20.0 10.0 20.0 20.0 20.0 20.0C20.0 20.0 10.0 20.0 10.0 20.0C10.0 20.0 10.0 10.0 10.0 10.0C10.0 10.0 10.0 10.0 10.0 10.0 z"')
        assert_equal(newrecord["group"][0]['maxX'], '20.0')
        assert_equal(newrecord["group"][0]['maxY'], '20.0')
        assert_equal(newrecord["group"][0]['minX'], '10.0')
        assert_equal(newrecord["group"][0]['minY'], '10.0')
        assert_equal(newrecord["group"][0]['x'], '10')
        assert_equal(newrecord["group"][0]['y'], '30')

    def test_analyzeSVG5(self):

        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?>\
            <g transform='rotate(40)'>\
                <path \
                    transform='rotate(10)' \
                    x='10' \
                    y='30' \
                    d='M 0,0 L 10,0 L 10,10 L 0,10 L 0,0 z' />\
            </g>")
        group = dom1.getElementsByTagName('g')
        newrecord = ia.extract_g(group[0], "")
        assert_equal(newrecord["group"][0]['path'], '"M0.0 0.0C0.0 0.0 9.64966028492 -2.62374853704 9.64966028492 -2.62374853704C9.64966028492 -2.62374853704 12.273408822 7.02591174788 12.273408822 7.02591174788C12.273408822 7.02591174788 2.62374853704 9.64966028492 2.62374853704 9.64966028492C2.62374853704 9.64966028492 0.0 0.0 0.0 0.0C0.0 0.0 0.0 0.0 0.0 0.0 z"')
        assert_equal(newrecord["group"][0]['maxX'], '12.273408822')
        assert_equal(newrecord["group"][0]['maxY'], '9.64966028492')
        assert_equal(newrecord["group"][0]['minX'], '0.0')
        assert_equal(newrecord["group"][0]['minY'], '-2.62374853704')
        assert_equal(newrecord["group"][0]['x'], '10')
        assert_equal(newrecord["group"][0]['y'], '30')

    def test_analyzeSVG6(self):

        # check image included in a group
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString('<?xml version="1.0" ?> \
            <svg xmlns:xlink="http://www.w3.org/1999/xlink">\
                <g>\
                    <image \
                        xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH3gofDSYCgyL5zAAAAlVJREFUOMttk01IVFEUx3/3zodjZoVJWpuytDSS3kMSKneRRtuSdq2sUSGYje3aZNGHm9EyTRetIhUiCAkjC8KgFsJ7JBgKSUE5KpNo2TjOzLu3xczTl/hf3Xu+z/+cI8jBiFrYERMjalUC14CzQFlOPQOMAt12xJx0bQHEJud+oMkNKgN5qEwatMKDPjtihl0f4XEeB2pcK+2kmbrXSOn5VnYZ9WzCZ8AAtPRkrvFaqFSStYXv/By6zRaoBnrsiInM9dyEkCDkuoXOpEEIZF4+ybmvOKt/vHoBhI2oVe4rPdd8U0jfifmRHhIzFqG95TiJZaY7GtGZNCr5l/iHQeZHnyD9QQoOmt5KpDCi1rQM5ldMtNXirK6glQIBQvrwhQrYadSD1ixZI6hUkpKGq5Q0hEFrgIwwolYKCAgpmX3ZyeLH5zjJFQKFxRy99Q6dSWVr9geZvHGG/ZfvsK3MBHRW7gbIFiRZeP2Y2KtHHGkbJLTvMPGxARCC4rpLW5GJBL5tMCNI/44DkLfnAFopluwRZl90uCVvhiOBN+vMK8WOqjqEkMSGuxBScqi1n+r7n0CIbDtCeAP0SqB7468pqKhFKUV8bIBfY8/whQrxhbYTG+5i4vpJfgy1e8fZ6a5yH3DFla7NzfDl7gWklIhAELTOjlQpjrW/xV9YBNBrR8wW7ypbwPHskgicxDLx909ZHB9GSj9Fpy+y+1QjMhgCmAIq/zum3LsHCK+TKiUIX44fxz2qXjtitriJJeCeprYjZnMu8gMgoZVCO2m0k06g1UOgyusM8A8PqAKAYqQluwAAAABJRU5ErkJggg=="\
                        width="50"\
                        height="50">\
                    </image>\
                </g>\
            </svg>')
        group = dom1.getElementsByTagName('g')
        ia.backgroundNode = 0
        newrecord = ia.extract_g(group[0], "")
        assert_equal(newrecord["group"][0]['x'],'0')
        assert_equal(newrecord["group"][0]['y'],'0')        
        assert_equal(newrecord["group"][0]['width'],'50')
        assert_equal(newrecord["group"][0]['height'],'50')                

    def test_analyzeSVG7(self):

        # check rect included in a group
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString('<?xml version="1.0" ?>\
            <svg>\
                <g>\
                    <rect width="50" height="50"></rect>\
                </g>\
            </svg>')
        group = dom1.getElementsByTagName('g')
        newrecord = ia.extract_g(group[0], "")
        assert_equal(newrecord["group"][0]['x'], '0')
        assert_equal(newrecord["group"][0]['y'], '0')
        assert_equal(newrecord["group"][0]['width'], '50')
        assert_equal(newrecord["group"][0]['height'], '50')

    def test_analyzeSVG8(self):

        # check groups included in a group
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString('<?xml version="1.0" ?> \
            <svg> \
                <g> \
                    <rect width="50" height="50"></rect> \
                    <g> \
                        <desc>description</desc> \
                        <title>title</title> \
                    </g> \
                </g> \
            </svg>')
        group = dom1.getElementsByTagName('g')
        newrecord = ia.extract_g(group[0], "")
        assert_equal(newrecord['detail'], 'description')
        assert_equal(newrecord['title'], 'title')

    def test_analyzeSVG9(self):

        # check metadatas
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString('<?xml version="1.0" ?> \
            <svg \
                xmlns:dc="http://purl.org/dc/elements/1.1/" \
                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" > \
                <metadata> \
                    <rdf:RDF> \
                        <dc:title>title</dc:title>\
                        <dc:date>16/06/2014</dc:date>\
                        <dc:creator><dc:title>creator</dc:title></dc:creator>\
                        <dc:rights><dc:title>GPL</dc:title></dc:rights>\
                        <dc:publisher><dc:title>publisher</dc:title></dc:publisher>\
                        <dc:language>FR</dc:language>\
                        <dc:subject>\
                            <rdf:li>keyword1</rdf:li>\
                            <rdf:li>keyword2</rdf:li>\
                        </dc:subject>\
                        <dc:contributor><dc:title>contributor</dc:title></dc:contributor>\
                    </rdf:RDF> \
                </metadata> \
            </svg>')
        ia.extractMetadatas(dom1)
        assert_equal(ia.scene['title'], 'title')
        assert_equal(ia.scene['date'], '16/06/2014')
        assert_equal(ia.scene['creator'], 'creator')
        assert_equal(ia.scene['rights'], 'GPL')
        assert_equal(ia.scene['publisher'], 'publisher')
        assert_equal(ia.scene['language'], 'FR')
        assert_equal(ia.scene['keywords'], 'keyword1,keyword2')
        assert_equal(ia.scene['contributor'], 'contributor')

    def test_analyzeSVG10(self):

        # check invalid path
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?>\
            <svg>\
                <path d='' />\
            </svg>")
        path = dom1.getElementsByTagName('path')
        newrecord = ia.extract_path(path[0], "")
        assert_equal(newrecord, None)

    def test_analyzeSVG11(self):

        # check invalid rectangle
        console = LoggerMock()
        ia = iaObject(console)
        dom1 = minidom.parseString("<?xml version='1.0' ?>\
            <svg>\
                <rect width='' height='' />\
            </svg>")
        detail = dom1.getElementsByTagName('rect')
        newrecord = ia.extract_rect(detail[0], "")
        assert_equal(newrecord, None)

    def test_generateJSON(self):

        # check generateJSON
        tempDirSvg = tempfile.gettempdir()
        maxNumPixels = 5 * 1024 * 1024
        currentDir  = os.path.dirname(os.path.realpath(__file__))
        with open(currentDir + "/fixtures/generic1.svg", "r") as genericSvg:
            tempContent = genericSvg.read()
            tempContent = tempContent.replace("file://fixtures", "file://" + currentDir + "/fixtures")

        with open(tempDirSvg + "/generic1.svg", "w") as tempSvg:
            tempSvg.write(tempContent)

        console = LoggerMock()
        ia = iaObject(console)
        ia.analyzeSVG(tempSvg.name, maxNumPixels)

        ia.generateJSON()
        temp_content = ia.jsonContent
        #with open(currentDir + '/fixtures/temp.js', 'w') as js:
        #    js.write(temp_content)
        with open(currentDir + '/fixtures/generic1.js') as js:
            assert_equal(js.read(),temp_content)



#!/usr/bin/python
# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@crdp.ac-versailles.fr

# dom manipulation
from xml.dom import minidom
import re

import gettext
import locale

class hook:
    """do some stuff during image active generations"""

    def __init__(self, root, iaobject, PageFormatter, langPath):
        """Init"""

        try:
            t = gettext.translation("xia-converter", langPath, languages=[locale.getdefaultlocale()[0]])
        except:
            t = gettext.translation("xia-converter", langPath, languages=['en_US'])
        translate = t.ugettext
        self.root = root
        self.iaobject = iaobject
        self.PageFormatter = PageFormatter
        self.tooltip = translate("export game1clic")
        self.score = "0"
        self.game_not_configured = translate("You win !")
        self.message = self.game_not_configured
        self.loading = translate("loading")

    def generateIndex(self,filePath, templatePath):
        """ generate index file"""
        
        self.score = "0"
        self.message = self.game_not_configured

        self.score2 = "0"
        self.message2 = self.game_not_configured
        
        score = re.search('<score>(.*?)</score>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if score:
            self.score = score.group(1)

        message = re.search('<message>(.*?)</message>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if message:
            self.message = message.group(1)

        score2 = re.search('<score2>(.*?)</score2>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if score2:
            self.score2 = score2.group(1)

        message2 = re.search('<message2>(.*?)</message2>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if message2:
            self.message2 = message2.group(1)
       
       
        final_str = u'<article class="message_success" id="message_success" data-score="' + self.score + '">\n'
        final_str += '<img id="popup_toggle" src="{{LogoHide}}" alt="toggle"/>\n'
        final_str += u'  <div id="message_success_content">' + self.PageFormatter(self.message).print_html() + u'</div>\n'
        final_str += u'</article>\n'

        final_str += u'<article class="message_success" id="message_success2" data-score="' + self.score2 + '">\n'
        final_str += '<img id="popup_toggle2" src="{{LogoHide}}" alt="toggle"/>\n'
        final_str += u'  <div id="message_success_content2">' + self.PageFormatter(self.message2).print_html() + u'</div>\n'
        final_str += u'</article>\n'
            
        for i, detail in enumerate(self.iaobject.details):

            tooltip_state = ""
            tooltip = re.search('<tooltip>(.*)</tooltip>', detail["detail"], re.IGNORECASE|re.DOTALL)
            if tooltip:
                tooltip_state = tooltip.group(1)            

            final_str += u'<article class="detail_content" data-kinetic_id="'+detail["id"]+'" data-tooltip="' + tooltip_state + '" data-options="' + detail['options'] + u'" id="article-'+unicode(str(i), "utf8") + u'">\n'
            final_str += u'  <h1>' + detail['title'] + u'</h1>\n'
            final_str += u'  <p>' + self.PageFormatter(detail["detail"]).print_html() + u'<p>\n'
            final_str += u'</article>\n'

        with open(templatePath,"r") as template:
            final_index = template.read().decode("utf-8")
            metadatas = ""
            if self.iaobject.scene["creator"]:
                metadatas += self.iaobject.scene["creator"] + "<br/>"
            if self.iaobject.scene["rights"]:
                metadatas += self.iaobject.scene["rights"] + "<br/>"
            if self.iaobject.scene["publisher"]:
                metadatas += self.iaobject.scene["publisher"] + "<br/>"
            if self.iaobject.scene["identifier"]:
                metadatas += self.iaobject.scene["identifier"] + "<br/>"
            if self.iaobject.scene["coverage"]:
                metadatas += self.iaobject.scene["coverage"] + "<br/>"
            if self.iaobject.scene["source"]:
                metadatas += self.iaobject.scene["source"] + "<br/>"
            if self.iaobject.scene["relation"]:
                metadatas += self.iaobject.scene["relation"] + "<br/>"
            if self.iaobject.scene["language"]:
                metadatas += self.iaobject.scene["language"] + "<br/>"
            if self.iaobject.scene["contributor"]:
                metadatas += self.iaobject.scene["contributor"] + "<br/>"
            if self.iaobject.scene["date"]:
                metadatas += self.iaobject.scene["date"] + "<br/>"

            final_index = final_index.replace("{{METADATAS}}", metadatas)
            final_index = final_index.replace("{{AUTHOR}}", self.iaobject.scene["creator"])
            final_index = final_index.replace("{{DESCRIPTION}}", self.iaobject.scene["description"])
            final_index = final_index.replace("{{INTRODUCTION}}", self.PageFormatter(self.iaobject.scene["description"]).print_html())
            final_index = final_index.replace("{{KEYWORDS}}", self.iaobject.scene["keywords"])
            final_index = final_index.replace("{{TITLE}}", self.iaobject.scene["title"])
            final_index = final_index.replace("{{CONTENT}}", final_str)
            final_index = final_index.replace("{{LOADING}}", self.loading)
            if self.root.index_standalone:
                xiaWebsite = "http://xia.dane.ac-versailles.fr/network/delivery/game1clic"
                final_index = final_index.replace("{{MainCSS}}", xiaWebsite + "/css/main.css")
                final_index = final_index.replace("{{LogoLoading}}",  xiaWebsite + "/img/xia.png")
                final_index = final_index.replace("{{LogoHide}}",  xiaWebsite + "/img/hide.png")
                final_index = final_index.replace("{{LogoClose}}", xiaWebsite + "/img/close.png")
                final_index = final_index.replace("{{datasJS}}", "<script>" + self.iaobject.jsonContent + "</script>")
                final_index = final_index.replace("{{lazyDatasJS}}", '')
                final_index = final_index.replace("{{JqueryJS}}", "https://code.jquery.com/jquery-1.11.1.min.js")
                final_index = final_index.replace("{{sha1JS}}", xiaWebsite + "/js/git-sha1.min.js")
                final_index = final_index.replace("{{kineticJS}}", xiaWebsite + "/js/kinetic-xia.min.js")
                final_index = final_index.replace("{{xiaJS}}", xiaWebsite + "/js/xia.js")
                final_index = final_index.replace("{{hooksJS}}", xiaWebsite + "/js/hooks.js")
                final_index = final_index.replace("{{labJS}}", "https://cdnjs.cloudflare.com/ajax/libs/labjs/2.0.3/LAB.min.js")
            else:
                final_index = final_index.replace("{{MainCSS}}", "css/main.css")
                final_index = final_index.replace("{{LogoLoading}}",  "img/xia.png")
                final_index = final_index.replace("{{LogoHide}}", "img/hide.png")
                final_index = final_index.replace("{{LogoClose}}", "img/close.png")
                final_index = final_index.replace("{{datasJS}}", "")
                final_index = final_index.replace("{{lazyDatasJS}}", '.script("datas/data.js")')
                final_index = final_index.replace("{{JqueryJS}}", "js/jquery.min.js")
                final_index = final_index.replace("{{sha1JS}}", "js/git-sha1.min.js")
                final_index = final_index.replace("{{kineticJS}}", "js/kinetic-xia.min.js")
                final_index = final_index.replace("{{xiaJS}}", "js/xia.js")
                final_index = final_index.replace("{{hooksJS}}", "js/hooks.js")
                final_index = final_index.replace("{{labJS}}", "js/LAB.min.js")  
        with open(filePath,"w") as indexfile:
            indexfile.write(final_index.encode("utf-8"))



# -*- coding: utf-8 -*-
from __future__ import unicode_literals 
#from pyvirtualdisplay import Display
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.support.ui import Select
from selenium.common.exceptions import NoSuchElementException
from selenium.common.exceptions import NoAlertPresentException
import unittest, time, re
import os

if os.name != 'nt':
    from pyvirtualdisplay import Display
    display = Display(visible=0, size=(1024, 768))
    display.start()



class Test(unittest.TestCase):
    def setUp(self):
        self.driver = webdriver.Firefox()
        self.driver.implicitly_wait(30)
        self.base_url = "file://"+os.path.dirname(os.path.abspath(__file__))+"/index.html"
        self.maxDiff=5000
        self.verificationErrors = []
        self.accept_next_alert = True
    
    def test_init(self):
        driver = self.driver
        driver.get(self.base_url)
        self.assertEqual("Titre du document", driver.find_element_by_id("title").text)
        self.assertTrue(driver.find_element_by_id("title").is_displayed())
        self.assertEqual("Titre de l'image", driver.find_element_by_id("collapsecomment-heading").text)
        self.assertTrue(driver.find_element_by_id("collapsecomment-heading").is_displayed())
        self.assertEqual("Titre du rectangle ***gras*** **italique**", driver.find_element_by_id("collapse0-heading").text)
        self.assertTrue(driver.find_element_by_id("collapse0-heading").is_displayed())
        self.assertEqual("Titre de l'ellipse", driver.find_element_by_id("collapse1-heading").text)
        self.assertTrue(driver.find_element_by_id("collapse1-heading").is_displayed())
        self.assertEqual(u"Titre de l'étoile {{{Texte brut}}}", driver.find_element_by_id("collapse2-heading").text)
        self.assertTrue(driver.find_element_by_id("collapse2-heading").is_displayed())
        self.assertEqual("Titre de ligne", driver.find_element_by_id("collapse3-heading").text)
        self.assertTrue(driver.find_element_by_id("collapse3-heading").is_displayed())
        self.assertEqual("Titre bezier", driver.find_element_by_id("collapse4-heading").text)
        self.assertTrue(driver.find_element_by_id("collapse4-heading").is_displayed())
        self.assertEqual("son 2", driver.find_element_by_id("collapse5-heading").text)
        self.assertTrue(driver.find_element_by_id("collapse5-heading").is_displayed())
        self.assertEqual("Son 1", driver.find_element_by_id("collapse6-heading").text)
        self.assertTrue(driver.find_element_by_id("collapse6-heading").is_displayed())
        self.assertEqual("""Description de l'image<video controls="" preload="none" data-state="none">
	            <source type="video/mp4" src="../media-share/1.mp4">
	            <source type="video/ogg" src="../media-share/1.ogv">
	            <source type="video/webm" src="../media-share/1.webm">
            </video>

        """, driver.find_element_by_xpath("//div[@id='collapsecomment']/div").get_attribute('innerHTML'))
        self.assertTrue(self.is_element_present(By.XPATH, "//div[@id='collapsecomment']/div/video"))

        
        assert """Description du rectangle <b>gras</b> <em>italique</em><div style="margin-top:5px;margin-bottom:5px;"><a class="button" href="#" data-password=""" in driver.find_element_by_xpath("//div[@id='collapse0']/div").get_attribute('innerHTML')
        assert """Voici la vidéo :<video controls="" preload="none" data-state="autostart">
	            <source type="video/mp4" src="../media-share/1.mp4">
	            <source type="video/ogg" src="../media-share/1.ogv">
	            <source type="video/webm" src="../media-share/1.webm">
            </video>""" in driver.find_element_by_xpath("//div[@id='collapse0']/div").get_attribute('innerHTML')
        self.assertTrue(self.is_element_present(By.XPATH, "id('collapse0')/div/video"))
        self.assertEqual("""
          <div class="accordion-inner">Description de l'ellipse<ul>
<li>une liste  <a href="http://dane.ac-versailles.fr" target="_blank">Le site de la Dane</a></li><li>de puces</li><ul>
<li>sur 2</li><li>niveaux</li><br>
</ul>
</ul>
Quelle est la bonne réponse ?<img src="../media-share/1.jpg">

          </div>
      """, driver.find_element_by_xpath("//div[@id='collapse1']").get_attribute('innerHTML'))
        self.assertTrue(self.is_element_present(By.XPATH, "id('collapse1')/div/img"))
        self.assertEqual("""
          <div class="accordion-inner">Description de l'étoile<ul>
 <a href="http://dane.ac-versailles.fr" target="_blank">Le site de la Dane</a></ul>
<pre>Texte brut</pre>
<br>
<img src="../media-share/1.gif">

          </div>
      """, driver.find_element_by_xpath("//div[@id='collapse2']").get_attribute('innerHTML'))
        self.assertTrue(self.is_element_present(By.XPATH, "id('collapse2')/div/img"))
        self.assertEqual("""
          <div class="accordion-inner">Description de ligne1<br>
<video controls="" preload="none" data-state="autostart">
	            <source type="video/mp4" src="../media-share/1.mp4">
	            <source type="video/ogg" src="../media-share/1.ogv">
	            <source type="video/webm" src="../media-share/1.webm">
            </video>
<br>

          </div>
      """, driver.find_element_by_xpath("//div[@id='collapse3']").get_attribute('innerHTML'))
        self.assertTrue(self.is_element_present(By.XPATH, "id('collapse3')/div/video"))
        self.assertEqual("""
          <div class="accordion-inner">Description de beziertracer
<hr>
une ligne<br>
<img src="../media-share/1.png">

          </div>
      """, driver.find_element_by_xpath("//div[@id='collapse4']").get_attribute('innerHTML'))
        self.assertTrue(self.is_element_present(By.XPATH, "id('collapse4')/div/img"))
        assert """<div class="accordion-inner">le son 2 ! <audio controls="" data-state="autostart">
	            <source type="audio/ogg" src="../media-share/1.ogg">
	            <source type="audio/mp3" src="../media-share/1.mp3">
            </audio>
<div style="margin-top:5px;margin-bottom:5px;"><a class="button" href="#" data-target=""" in driver.find_element_by_xpath("//div[@id='collapse5']").get_attribute('innerHTML')
        assert """La réponse 2</ul>
</div>
LA réponse à la question<br>

          </div>
      """ in driver.find_element_by_xpath("//div[@id='collapse5']").get_attribute('innerHTML')
        self.assertTrue(self.is_element_present(By.XPATH, "id('collapse5')/div/audio"))
        self.assertEqual("""
          <div class="accordion-inner">le son 1 !<audio controls="" data-state="none">
	            <source type="audio/ogg" src="../media-share/1.ogg">
	            <source type="audio/mp3" src="../media-share/1.mp3">
            </audio>

          </div>
      """, driver.find_element_by_xpath("//div[@id='collapse6']").get_attribute('innerHTML'))
        self.assertTrue(self.is_element_present(By.XPATH, "id('collapse6')/div/audio"))
        self.check_element()
        driver.find_element_by_css_selector("a.infos").click()
        self.assertEqual("Michaël Nourry", driver.find_element_by_xpath("//article[@id='popup_text']").text)

        self.check_element("id('popup')")
        
        
    def test_nav_1(self):
        driver = self.driver
        driver.get(self.base_url)
        driver.find_element_by_id("collapsecomment-heading").click()
        self.check_element("collapsecomment")
        driver.find_element_by_id("collapse0-heading").click()
        self.check_element("collapse0")
        driver.execute_script(self.click_zone("Son 1"))
        driver.execute_script(self.click_zone("Son 1"))
        self.check_element("collapse6")
        driver.find_element_by_xpath("//div[@id='canvas']/div/canvas[4]").click()
        self.check_element("collapse6")
        driver.find_element_by_id("collapse5-heading").click()
        self.check_element("collapse5")
        driver.find_element_by_id("collapse6-heading").click()
        self.check_element("collapse6")
        driver.find_element_by_id("collapsecomment-heading").click()
        time.sleep(1)
        driver.find_element_by_id("collapse0-heading").click()
        time.sleep(3)
        driver.find_element_by_link_text("Super ma question").click()
        driver.find_element_by_xpath("//input[@type='text']").clear()
        driver.find_element_by_xpath("//input[@type='text']").send_keys("147")
        driver.find_element_by_css_selector("input[type=\"submit\"]").click()
        driver.find_element_by_css_selector("input[type=\"submit\"]").click()
        assert "La réponse !" not in driver.find_element_by_xpath("//div[@id='collapse0']/div").text 
        
        driver.find_element_by_xpath("//input[@type='text']").clear()
        driver.find_element_by_xpath("//input[@type='text']").send_keys("1a")
        driver.find_element_by_css_selector("input[type=\"submit\"]").click()
        assert "La réponse !" in  driver.find_element_by_xpath("//div[@id='collapse0']/div").text


    def test_nav_2(self):
        driver = self.driver
        driver.get(self.base_url)
        driver.find_element_by_css_selector("a.infos").click()
        self.check_element("popup")
        driver.find_element_by_id("popup_close").click()
        self.check_element()
        driver.execute_script(self.click_zone("son 2"))
        self.check_element("collapse5")
        driver.find_element_by_id("collapse0-heading").click()
        self.check_element("collapse0")
        driver.find_element_by_id("collapse1-heading").click()
        self.check_element("collapse1")
        driver.find_element_by_id("collapse2-heading").click()
        self.check_element("collapse2")
        driver.find_element_by_id("collapse4-heading").click()
        self.check_element("collapse4")
        driver.find_element_by_id("collapse5-heading").click()
        self.check_element("collapse5")
        driver.find_element_by_id("collapse6-heading").click()
        self.check_element("collapse6")
        driver.find_element_by_id("collapsecomment-heading").click()
        self.check_element("collapsecomment")
        driver.find_element_by_id("collapse0-heading").click()
        self.check_element("collapse0")
        self.assertEqual("""Description du rectangle gras italique
Super ma question
Voici la vidéo :""", driver.find_element_by_css_selector("#collapse0 > div.accordion-inner").text)
        driver.find_element_by_id("collapsecomment-heading").click()
        self.check_element("collapsecomment")
        driver.find_element_by_id("collapse0-heading").click()
        self.check_element("collapse0")
        driver.find_element_by_id("collapse4-heading").click()
        self.check_element("collapse4")

    def test_init_1(self):
        driver = self.driver
        self.base_url = "file://"+os.path.dirname(os.path.abspath(__file__))+"/1.html"
        self.test_init()

    def test_nav_1_1(self):
        driver = self.driver
        self.base_url = "file://"+os.path.dirname(os.path.abspath(__file__))+"/1.html"
        self.test_nav_1()

    def test_nav_2_1(self):
        driver = self.driver
        self.base_url = "file://"+os.path.dirname(os.path.abspath(__file__))+"/1.html"
        self.test_nav_2()


    def is_element_present(self, how, what):
        try: self.driver.find_element(by=how, value=what)
        except NoSuchElementException, e: return False
        return True
    
    def is_alert_present(self):
        try: self.driver.switch_to_alert()
        except NoAlertPresentException, e: return False
        return True
    
    def close_alert_and_get_its_text(self):
        try:
            alert = self.driver.switch_to_alert()
            alert_text = alert.text
            if self.accept_next_alert:
                alert.accept()
            else:
                alert.dismiss()
            return alert_text
        finally: self.accept_next_alert = True
    def click_zone(self,zone):
        return """
		    for (var i in Kinetic.shapes) {
			    if (Kinetic.shapes[i].attrs['name'] == '"""+zone+"""') {
				    Kinetic.shapes[i].fire('click');
                    break;
			    }
		    }
           """
    def check_element(self,visible="0XXXX0XXXX0"):
        time.sleep(1)
        driver = self.driver
        elements = [
            "id('popup')",
            "id('collapsecomment')/div",
            "//div[@id='collapsecomment']/div/video",
            "id('collapse0')/div",
            "id('collapse0')/div/video",
            "id('collapse1')/div/ul",
            "id('collapse1')/div/img",
            "id('collapse2')/div",
            "id('collapse2')/div/img",
            "id('collapse3')/div",
            "id('collapse3')/div/video",
            "id('collapse4')/div",
            "id('collapse4')/div/img",
            "id('collapse5')/div",
            "id('collapse5')/div/audio",
            "id('collapse6')/div",
            "id('collapse6')/div/audio"
            ]
        for id in elements:
            if id.find(visible)+1:
                self.assertTrue(driver.find_element_by_xpath(id).is_displayed())
            else:
                self.assertFalse(driver.find_element_by_xpath(id).is_displayed())

    def tearDown(self):
        self.driver.quit()
#        self.assertEqual([], self.verificationErrors)
#        display.stop()

if __name__ == "__main__":
    unittest.main()
 



#!/usr/bin/python
# -*- coding: utf-8 -*-
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>
#   
# @author : pascal.fautrero@crdp.ac-versailles.fr

# dom manipulation
from xml.dom import minidom
import re

import gettext
import locale

class hook:
    """do some stuff during image active generations"""

    def __init__(self, root, iaobject, PageFormatter, langPath):
        """Init"""
        try:
            t = gettext.translation("xia-converter", langPath, languages=[locale.getdefaultlocale()[0]])
        except:
            t = gettext.translation("xia-converter", langPath, languages=['en_US'])
        translate = t.ugettext
        self.root = root
        self.iaobject = iaobject
        self.PageFormatter = PageFormatter
        self.tooltip = translate("export gameDragAndDrop")        
        self.score = "0"
        self.collisions = "off"
        self.message = translate("You win !")
        self.loading = translate("loading")

    def generateIndex(self,filePath, templatePath):
        """ generate index file"""

        self.score = "0"
        self.collisions = "off"
        self.magnet = "off"
        
        score = re.search('<score>(.*)</score>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if score:
            self.score = score.group(1)

        message = re.search('<message>(.*)</message>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if message:
            self.message = message.group(1)

        collisions = re.search('<collisions>(.*)</collisions>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if collisions:
            self.collisions = collisions.group(1)        

        magnet = re.search('<magnet>(.*)</magnet>', self.iaobject.scene["intro_detail"], re.IGNORECASE|re.DOTALL)
        if magnet:
            self.magnet = magnet.group(1)        
        
        final_str = u'<article class="message_success" id="message_success" data-magnet="' + self.magnet + '" data-collisions="' + self.collisions + '" data-score="' + self.score + '">\n'
        final_str += '<div class="message_success_border">\n'
        final_str += '<img id="popup_toggle" src="{{LogoHide}}" alt="toggle"/>\n'
        final_str += u'  <div id="message_success_content">' + self.PageFormatter(self.message).print_html() + u'</div>\n'
        final_str += '</div>\n'
        final_str += u'</article>\n'

        for i, detail in enumerate(self.iaobject.details):

            target_id = ""
            target = re.search('<target>(.*)</target>', detail["detail"], re.IGNORECASE|re.DOTALL)
            if target:
                target_id = target.group(1)

            magnet_state = "off"
            magnet = re.search('<magnet>(.*)</magnet>', detail["detail"], re.IGNORECASE|re.DOTALL)
            if magnet:
                magnet_state = magnet.group(1)

            collision_state = "on"
            collision = re.search('<collisions>(.*)</collisions>', detail["detail"], re.IGNORECASE|re.DOTALL)
            if collision:
                collision_state = collision.group(1)

            tooltip_state = ""
            tooltip = re.search('<tooltip>(.*)</tooltip>', detail["detail"], re.IGNORECASE|re.DOTALL)
            if tooltip:
                tooltip_state = tooltip.group(1)

            final_str += u'<article class="detail_content" data-tooltip="'+ tooltip_state +'" data-collisions="'+ collision_state +'" data-magnet="'+ magnet_state +'" data-kinetic_id="'+detail["id"]+'" data-target="'+target_id+'" id="article-'+unicode(str(i), "utf8") + u'">\n'
            final_str += u'  <h1>' + detail['title'] + u'</h1>\n'
            final_str += u'  <p>' + self.PageFormatter(detail["detail"]).print_html() + u'<p>\n'
            final_str += u'</article>\n'

        with open(templatePath,"r") as template:
            final_index = template.read().decode("utf-8")

            metadatas = ""
            if self.iaobject.scene["creator"]:
                metadatas += self.iaobject.scene["creator"] + "<br/>"
            if self.iaobject.scene["rights"]:
                metadatas += self.iaobject.scene["rights"] + "<br/>"
            if self.iaobject.scene["publisher"]:
                metadatas += self.iaobject.scene["publisher"] + "<br/>"
            if self.iaobject.scene["identifier"]:
                metadatas += self.iaobject.scene["identifier"] + "<br/>"
            if self.iaobject.scene["coverage"]:
                metadatas += self.iaobject.scene["coverage"] + "<br/>"
            if self.iaobject.scene["source"]:
                metadatas += self.iaobject.scene["source"] + "<br/>"
            if self.iaobject.scene["relation"]:
                metadatas += self.iaobject.scene["relation"] + "<br/>"
            if self.iaobject.scene["language"]:
                metadatas += self.iaobject.scene["language"] + "<br/>"
            if self.iaobject.scene["contributor"]:
                metadatas += self.iaobject.scene["contributor"] + "<br/>"
            if self.iaobject.scene["date"]:
                metadatas += self.iaobject.scene["date"] + "<br/>"

            final_index = final_index.replace("{{METADATAS}}", metadatas)
            final_index = final_index.replace("{{AUTHOR}}", self.iaobject.scene["creator"])
            final_index = final_index.replace("{{DESCRIPTION}}", self.iaobject.scene["description"])
            final_index = final_index.replace("{{INTRODUCTION}}", self.PageFormatter(self.iaobject.scene["description"]).print_html())            
            final_index = final_index.replace("{{KEYWORDS}}", self.iaobject.scene["keywords"])
            final_index = final_index.replace("{{TITLE}}", self.iaobject.scene["title"])
            final_index = final_index.replace("{{CONTENT}}", final_str)
            final_index = final_index.replace("{{LOADING}}", self.loading)
            if self.root.index_standalone:
                xiaWebsite = "http://xia.dane.ac-versailles.fr/network/delivery/gameDragAndDrop"
                final_index = final_index.replace("{{MainCSS}}", xiaWebsite + "/css/main.css")
                final_index = final_index.replace("{{LogoHide}}",  xiaWebsite + "/img/hide.png")
                final_index = final_index.replace("{{LogoLoading}}",  xiaWebsite + "/img/xia.png")
                final_index = final_index.replace("{{LogoClose}}", xiaWebsite + "/img/close.png")
                final_index = final_index.replace("{{datasJS}}", "<script>" + self.iaobject.jsonContent + "</script>")
                final_index = final_index.replace("{{lazyDatasJS}}", '')
                final_index = final_index.replace("{{JqueryJS}}", "https://code.jquery.com/jquery-1.11.1.min.js")
                final_index = final_index.replace("{{sha1JS}}", xiaWebsite + "/js/git-sha1.min.js")
                final_index = final_index.replace("{{kineticJS}}", xiaWebsite + "/js/kinetic-xia.min.js")
                final_index = final_index.replace("{{xiaJS}}", xiaWebsite + "/js/xia.js")
                final_index = final_index.replace("{{hooksJS}}", xiaWebsite + "/js/hooks.js")
                final_index = final_index.replace("{{labJS}}", "https://cdnjs.cloudflare.com/ajax/libs/labjs/2.0.3/LAB.min.js")
            else:
                final_index = final_index.replace("{{MainCSS}}", "css/main.css")
                final_index = final_index.replace("{{LogoLoading}}",  "img/xia.png")
                final_index = final_index.replace("{{LogoHide}}",  "img/hide.png")
                final_index = final_index.replace("{{LogoClose}}", "img/close.png")
                final_index = final_index.replace("{{datasJS}}", "")
                final_index = final_index.replace("{{lazyDatasJS}}", '.script("datas/data.js")')
                final_index = final_index.replace("{{JqueryJS}}", "js/jquery.min.js")
                final_index = final_index.replace("{{sha1JS}}", "js/git-sha1.min.js")
                final_index = final_index.replace("{{kineticJS}}", "js/kinetic-xia.min.js")
                final_index = final_index.replace("{{xiaJS}}", "js/xia.js")
                final_index = final_index.replace("{{hooksJS}}", "js/hooks.js")
                final_index = final_index.replace("{{labJS}}", "js/LAB.min.js")
        with open(filePath,"w") as indexfile:
            indexfile.write(final_index.encode("utf-8"))



#!/usr/bin/python
# -*- coding: utf-8 -*-
"""
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""

# source code from http://code.activestate.com/recipes/576936/
import Tkinter
import time

class Splash:

    def __init__(self, root, file, wait):
        self.__root = root
        self.__file = file
        self.__wait = wait + time.clock()

    def enter(self):

        # Hide the root while it is built.
        #self.__root.withdraw()
        # Create components of splash screen.
        window = Tkinter.Toplevel(self.__root)
        canvas = Tkinter.Canvas(window)
        splash = Tkinter.PhotoImage(master=window, file=self.__file)
        # Get the screen's width and height.
        scrW = window.winfo_screenwidth()
        scrH = window.winfo_screenheight()
        # Get the images's width and height.
        imgW = splash.width()
        imgH = splash.height()
        # Compute positioning for splash screen.
        Xpos = (scrW - imgW) // 2
        Ypos = (scrH - imgH) // 2
        # Configure the window showing the logo.
        window.overrideredirect(True)
        window.geometry('+{}+{}'.format(Xpos, Ypos))
        # Setup canvas on which image is drawn.
        canvas.configure(width=imgW, height=imgH, highlightthickness=0)
        canvas.grid()
        # Show the splash screen on the monitor.
        canvas.create_image(imgW // 2, imgH // 2, image=splash)
        window.update()
        # Save the variables for later cleanup.
        self.__window = window
        self.__canvas = canvas
        self.__splash = splash

    def exit(self):
        # Ensure that required time has passed.
        now = time.clock()
        if now < self.__wait:
            time.sleep(self.__wait - now)
        # Free used resources in reverse order.
        del self.__splash
        self.__canvas.destroy()
        self.__window.destroy()
        # Give control back to the root program.
        self.__root.update_idletasks()
        self.__root.deiconify()
